import QtQuick 1.1
import com.nokia.meego 1.0

Window {
    id: root

    function formatMinutes(minutes) {
        if (minutes <= 60) {
            return minutes + " minutes"
        }
        else {
            var hours = Math.floor(minutes / 60)
            var remainingMins = minutes % 60
            if (remainingMins === 0) {
                return hours + " hours"
            } else {
                return hours + "h" + remainingMins + "mins"
            }
        }
    }

    function restoreToMinutes(restore) {
        var mins = 0;
        if (restore <= 4) {
            return restore * 15
        } else if (restore <= 18) {
            // One hour + upto 7 hours
            return 60 + (restore - 4) * 30
        }
        // 8 hours++
        return 480 + (restore - 18) * 60
    }

    function restoreText() {
       var minutes = root.restoreToMinutes(dRestore.restoreValue)
       var time = backend.timeCurrentPlusMinutes(minutes)
       return "Restore ringing in " + root.formatMinutes(minutes) + ", at " + time
    }

    Dialog {
        id: dRestore
        anchors.fill: parent
        //height: root.height
        property Style platformStyle: QueryDialogStyle {}
        property alias restoreValue: restoreSlider.value
        property alias volumeValue: volumeSlider.value

        // Overrides Dialog's behaviour of rejecting when clicking on an
        // non-used area.
        MouseArea {
            anchors.fill: parent
            z: -1
        }

        content: Item {
            id: contentItem
            width: parent.width
            height: selections.height;

            Column {
                id: selections
                property int spaceBetweenSections: 40
                property int sliderMargins: 50

                Text {
                    id: restoreLabel
                    wrapMode: Text.WordWrap
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: dRestore.width
                    horizontalAlignment: Text.AlignHCenter
                    font.pixelSize: 20;
                    color: "white"
                    text: restoreText()
                    function refreshText() {
                        text = restoreText()
                    }
                }

                Slider {
                    id: restoreSlider
                    valueIndicatorText: value + " minutes"
                    minimumValue: 1;
                    maximumValue: 22;
                    stepSize: 1
                    width: dRestore.width
                    onValueChanged: {
                        if (cancelTimer !== null) cancelTimer.running = false
                        restoreLabel.refreshText()
                    }
                }

                Rectangle {
                    height: parent.spaceBetweenSections
                    width: dRestore.width
                    color: root.color
                }

                Text {
                    id: volumeLabel
                    wrapMode: Text.WordWrap
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: dRestore.width
                    horizontalAlignment: Text.AlignHCenter
                    font.pixelSize: 20;
                    color: "white"
                    text: "Set ringing volume to " + volumeSlider.value + "%"
                }

                Slider {
                    id: volumeSlider
                    valueIndicatorText: value + "% volume"
                    // IMPROVE it might be cleaner to ask these from backend instead of hard-coding here
                    minimumValue: 40;
                    maximumValue: 100;
                    stepSize: 20
                    //valueIndicatorVisible: true
                    width: dRestore.width
                    onValueChanged: {
                        if (cancelTimer !== null) cancelTimer.running = false;
                    }
                }

                Rectangle {
                    height: parent.spaceBetweenSections
                    width: dRestore.width
                    color: root.color
                }
            }
        }

        buttons: ButtonRow {
            id: buttons
            style: ButtonStyle { }
            anchors.horizontalCenter: parent.horizontalCenter
            Button {
                text: "OK";
                onClicked: dRestore.accept()
            }
            Button {
                id: cancelButton
                text: "Cancel" + (cancelTimer.running ? " in " + cancelTimer.countDown + "s" : "");
                onClicked: dRestore.reject()
            }
            Timer {
                id: cancelTimer
                interval: 1000;
                repeat: true
                property int countDown

                onTriggered: {
                    countDown--
                    if (countDown == 0) {
                        cancelButton.clicked();
                    }
                }
            }
        }
        onAccepted: {
            console.log("onAccepted")
            backend.restoreRingingIn(root.restoreToMinutes(dRestore.restoreValue), volumeValue)
        }
        onRejected: {
            console.log("onRejected")
            backend.close();
        }
        onStatusChanged: {
            console.log("onStatusChanged", status)

            if (status == 1) {
                cancelTimer.countDown = 15
                cancelTimer.running = true
                restoreLabel.refreshText()
            } else {
                cancelTimer.running = false
            }
        }

    }

    Connections {
        target: backend
        onOpenTimeoutDialog: {
            dRestore.open();
        }
    }

    Component.onCompleted: {
        theme.inverted = true
    }

}
